package me.picnicapp.sample.picnicsample;

import android.app.Application;

import java.util.ArrayList;

import me.picnicapp.sdk.ar.ARSettings;
import me.picnicapp.sdk.content.Content;
import me.picnicapp.sdk.content.ContentLoader;
import me.picnicapp.sdk.map.MapSettings;
import me.picnicapp.sdk.picnic.Picnic;
import me.picnicapp.sdk.picnic.PicnicContentsManager;

public class App extends Application {
    @Override
    public void onCreate() {
        super.onCreate();

        // picnicのSDKを初期化
        Picnic.initialize(this, "your-api-key");
        Picnic.setHowtoActivity(HowtoActivity.class);

        // コンテンツをpicnicSDKに登録
        ArrayList<Content> contents = ContentLoader.readJsonFromResource(this, R.raw.contents);
        PicnicContentsManager.setContents(contents);

        // AR画面の初期設定を行う
        // カメラの画角
        ARSettings.setViewAngle(35);
        // 一度に表示するコンテンツ数の上限を指定する
        // (1度に大量のコンテンツを表示するとカメラがコンテンツで埋もれてしまうため)
        ARSettings.setDisplayContentsLimit(20);
        // カメラに浮かぶARタグは、距離によってサイズが変わる。
        // 現在位置から近いほど大きく表示される。
        // コンテンツに近づいた時に、ARタグが最大サイズで表示される距離を設定する。
        ARSettings.setMaxSizeDistance(30);
        // カメラに浮かぶARタグは、距離によってサイズが変わる。
        // 現在位置から遠いほど小さく表示される。
        // コンテンツから離れた時に、ARタグが表示されなくなる距離を設定する。
        ARSettings.setMinSizeDistance(200);
        // コンテンツに近づいた際の、ARタグの最大表示サイズ
        ARSettings.setMaxSizeRatio(0.4f);
        // コンテンツから遠ざかって、表示範囲ギリギリになった際の、ARタグの最小表示サイズ
        ARSettings.setMinSizeRatio(0.05f);
        // 地図画面に移動するボタンをAR画面上に表示するか
        ARSettings.setIsVisibleMapButton(true);

        // 地図画面の初期設定を行う
        // 緯度
        MapSettings.setInitialLatitude(35.689560d);
        // 経度
        MapSettings.setInitialLongitude(139.691783d);
        // 地図拡大率(2〜21で指定。数値が大きほど拡大表示される。)
        MapSettings.setInitialZoomLevel(17f);
        // AR画面に移動するボタンを地図画面上に表示するか
        MapSettings.setIsVisibleARButton(true);
    }

    // コンテンツリストを生成
    private ArrayList<Content> createContents() {
        ArrayList<Content> contents = new ArrayList<Content>();
        contents.add(createContent(1, 36.123, 138.123, "name1", "description1"));
        contents.add(createContent(2, 36.124, 138.124, "name2", "description2"));
        contents.add(createContent(3, 36.125, 138.125, "name3", "description3"));
        contents.add(createContent(4, 36.126, 138.126, "name4", "description4"));
        contents.add(createContent(5, 35.732594, 139.661480, "name5", "descriptiont5"));
        return contents;
    }

    // コンテンツを生成
    private Content createContent(int id, double lat, double lon, String name, String desc) {
        Content content = new Content();
        content.setId(id);
        content.setLatitude(lat);
        content.setLongitude(lon);
        content.getAttrs().setName(name);
        content.getAttrs().setDescription(desc);
        // 画像
        content.getImages().add("file:///android_asset/aaa.png");
        content.getAttrs().setImageUrl("file:///android_asset/bbb.png");
        content.getAttrs().setImageFrameUrl("file:///android_asset/bbb.png");
        return content;
    }
}
